@@ -1,8 +1,7 @@
-"""
-Collection of utitly functions for file I/O operations. The purpose is
+"""Collection of utitly functions for file I/O operations. The purpose is
 especially for scientific computing, thus numpy is involved in some functions.
 Copyright (C) 2022 Julian M. Kleber This program comes with ABSOLUTELY NO
-WARRANTY."
+WARRANTY.".
 
 author: Julian M. Kleber
 """
@@ -24,7 +23,11 @@ from .checks import check_make_file_name_suffix, check_make_dir
 LOGGER = logging.getLogger(__name__)
 
 
-def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
+def prepare_file_name_saving(
+    file_name: str,
+    prefix: Optional[str | Type[None]] = None,
+    suffix: Optional[str | Type[None]] = None,
+) -> str:
     """The prepare_file_name_saving function takes a prefix and file name as
     input. It checks to see if the directory exists, and makes it if not. Then
     it returns the full path of the file.
@@ -35,6 +38,12 @@ def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
 
     :doc-author: Julian M. Kleber
     """
+    if suffix == "" or suffix is None:
+        file_name, suffix = os.path.splitext(file_name)
+
+    if prefix == "" or prefix is None:
+        prefix, file_name = os.path.split(file_name)
+
     check_make_dir(prefix)
     file_name = make_full_filename(prefix, file_name)
     file_name = check_make_file_name_suffix(file_name, suffix)
@@ -42,11 +51,10 @@ def prepare_file_name_saving(prefix: str, file_name: str, suffix: str) -> str:
 
 
 def insert_string_in_file_name(file_name: str, insertion: str, suffix: str) -> str:
-    """
-    The insert_string_in_file_name function takes a file_name and inserts a string into the name.
-        The insertion is placed before the extension of the file_name, or if there is no extension,
-        it will be placed at the end of the file_name with an suffix specified by you.
-
+    """The insert_string_in_file_name function takes a file_name and inserts a
+    string into the name. The insertion is placed before the extension of the
+    file_name, or if there is no extension, it will be placed at the end of the
+    file_name with an suffix specified by you.
 
     :param file_name:str: Used to Specify the file name that you want to insert a string into.
     :param insertion:str: Used to Specify the string that will be inserted into the file name.
@@ -59,9 +67,10 @@ def insert_string_in_file_name(file_name: str, insertion: str, suffix: str) -> s
     root, ext = os.path.splitext(file_name)
 
     if suffix is None and not ext:
+
         raise ValueError(
-            "You must either specify an suffix in the file_name or pass an suffix through the \
-            suffix argument. For example the file_name could be 'foo.bar' or you pass \
+            "You must either specify an suffix in the file_name or pass an suffix through the\
+            suffix argument. For example the file_name could be 'foo.bar' or you pass\
             file_name'foo' with suffix = '.bar'"
         )
     if suffix is not None:
@@ -101,9 +110,8 @@ def make_full_filename(prefix: str, file_name: str) -> str:
 
 
 def load_json_from_file(file_name: str) -> Dict[Any, Any]:
-    """
-    The load_json_from_file function takes a file name as input and returns the contents of that
-    file in JSON format.
+    """The load_json_from_file function takes a file name as input and returns
+    the contents of that file in JSON format.
 
     :param file_name:str: Used to Specify the file name of the json file to be loaded.
     :return: A dictionary of the data in the file.
@@ -116,9 +124,7 @@ def load_json_from_file(file_name: str) -> Dict[Any, Any]:
     return data
 
 
-def save_json_to_file(
-    dictionary: Dict[Any, Any], file_name: Optional[str] = None, suffix: str = ".json"
-) -> None:
+def save_json_to_file(dictionary: Dict[Any, Any], file_name: str) -> None:
     """The save_json function saves a dictionary to a json file.
 
     :param dictionary: Used to store the data that will be saved.
@@ -149,9 +155,6 @@ def save_json_to_file(
             val = list(np_data)
         return val
 
-    if file_name is None:
-
-        file_name = make_date_file_name(suffix=suffix)
     with open(file_name, "w", encoding="utf-8") as out_file:
         json.dump(dictionary, out_file, default=convert)
         logging.info("Saved json %s", file_name)
@@ -178,8 +181,7 @@ def make_date_file_name(prefix: str = "", file_name: str = "", suffix: str = "")
 
 
 def delete_file(file_name: str) -> None:
-    """
-    The delete_file function deletes a file from the local directory.
+    """The delete_file function deletes a file from the local directory.
 
         Raises:
             Exception if there is an error deleting the specified file.
@@ -225,10 +227,9 @@ def search_subdirs(dir_name: str) -> Tuple[List[str], List[str]]:
 
 
 def write_tar(target_dir: str, file_name: str) -> None:
-    """
-    The write_tar function takes a target directory and an output name as arguments.
-    It then creates a tar file with the given output name, and adds all files in the
-    target directory to it.
+    """The write_tar function takes a target directory and an output name as
+    arguments. It then creates a tar file with the given output name, and adds
+    all files in the target directory to it.
 
     :param target_dir:str: Used to Specify the directory that you want to compress.
     :param out_name:str: Used to Specify the name of the tar file that will be created.
@@ -247,10 +248,9 @@ def write_tar(target_dir: str, file_name: str) -> None:
 
 
 def copy_dir(old_dir: str, new_dir: str, overwrite=True) -> None:
-    """
-    The copy_dir function takes two arguments, old_dir and new_dir.
-    It copies all files from the old directory to the new directory.
-    If either of these directories do not end with a "/", it will be added.
+    """The copy_dir function takes two arguments, old_dir and new_dir. It
+    copies all files from the old directory to the new directory. If either of
+    these directories do not end with a "/", it will be added.
 
     :param old_dir:str: Used to Specify the directory that you want to copy from.
     :param new_dir:str: Used to Specify the new directory that you want to copy your files into.
@@ -270,10 +270,9 @@ def copy_dir(old_dir: str, new_dir: str, overwrite=True) -> None:
 
 
 def convert_str_to_bool(bool_str: str) -> None:
-    """
-    The convert_str_to_bool function takes a string and converts it to a boolean.
-        The function is used in the main() function to convert the override value from
-        a string to a boolean.
+    """The convert_str_to_bool function takes a string and converts it to a
+    boolean. The function is used in the main() function to convert the
+    override value from a string to a boolean.
 
     :param bool_str:str: Used to Specify the type of data that will be passed into the function.
     :return: None.
